@@ -68,6 +68,8 @@ def parse_smart_filtering(filters: dict, indexed_columns:list=[]) -> dict:
     }
 
 
+DB_DATE_FORMAT = "YYYY-MM-DD HH:mm:ss"
+
 class Database(object):
     """
     :: Database
@@ -154,7 +156,7 @@ class Item(dict):
 
     def get(self, path:str, default:Any=None)->Any:
         """
-        Return a property by key/DotNotation
+        GET: Return a property by key/DotNotation
 
         ie: 
             #get("key.deep1.deep2.deep3")
@@ -170,7 +172,7 @@ class Item(dict):
 
     def set(self, path:str, value:Any):
         """
-        Set a property by key/DotNotation
+        SET: Set a property by key/DotNotation
 
         Args:
             path:str - the dotnotation path
@@ -183,9 +185,9 @@ class Item(dict):
         lib.dict_set(obj=data, path=path, value=value)
         self.update(data)
 
-    def remove(self, path:str):
+    def unset(self, path:str):
         """ 
-        Remove a property by key/DotNotation and return the value
+        UNSET: Remove a property by key/DotNotation and return the value
 
         Args:
             path:str
@@ -200,7 +202,7 @@ class Item(dict):
 
     def update(self, *a, **kw):
         """
-        Update the active Item
+        UPDATE: Update the active Item
 
         ie:
             #update(key=value, key2=value2, ...)
@@ -223,7 +225,7 @@ class Item(dict):
 
     def delete(self):
         """
-        Delete the Doument from the container
+        DELETE: Delete the Doument from the container
 
         Returns:
             None
@@ -233,7 +235,6 @@ class Item(dict):
 
     # ---
 
-
     def _req_int_prop(self, path:str) -> int:
         v = self.get(path)
         if v is None:
@@ -293,6 +294,27 @@ class Item(dict):
         self.set(path=path, value=v)
         return self.get(path)
 
+    def lremove(self, path:str, *values:List[Any]):
+        """
+        LREM: Remove items from a list
+
+        Args:
+            path:str - the dotnotation path
+            *values: set of items
+        Returns:
+            list: updated data
+        """
+        v = self._req_list_prop(path)
+        _removed = False
+        for val in values:
+            if val in v:
+                _removed = True
+                v.remove(val)
+        if _removed:
+            self.set(path=path, value=v)
+            return self.get(path)
+        return v
+
     def lpush(self, path:str, *values:List[Any]):
         """
         LPUSH: push item to the right of list. 
@@ -324,27 +346,6 @@ class Item(dict):
         self.set(path=path, value=v2)
         return self.get(path)
 
-    def lrem(self, path:str, *values:List[Any]):
-        """
-        LREM: Remove items from a list
-
-        Args:
-            path:str - the dotnotation path
-            *values: set of items
-        Returns:
-            list: updated data
-        """
-        v = self._req_list_prop(path)
-        _removed = False
-        for val in values:
-            if val in v:
-                _removed = True
-                v.remove(val)
-        if _removed:
-            self.set(path=path, value=v)
-            return self.get(path)
-        return v
-
     def lpop(self, path:str): 
         """
         Remove value at the end an array/list
@@ -615,6 +616,7 @@ class Container(object):
 
         _id = lib.gen_id()
         ts = lib.get_timestamp()
+        f_ts = ts.format(DB_DATE_FORMAT)
         doc.upate({
             "_id": _id,
             "_created_at": ts,
@@ -622,7 +624,7 @@ class Container(object):
         })
 
         xcolumns = ["_id", "_json", "_created_at", "_modified_at"]
-        xparams = [_id, lib.json_dumps(doc), lib.timestamp_to_str(ts), lib.timestamp_to_str(ts)]
+        xparams = [_id, lib.json_dumps(doc), f_ts, f_ts]
         q = "INSERT INTO %s " % self.name
         
         # indexed data
@@ -653,12 +655,13 @@ class Container(object):
         rdoc = self.find_one(_id=_id, _as_document=False)
         if rdoc:
             ts = lib.get_timestamp()
+            ts_f = ts.format(DB_DATE_FORMAT)
             _doc = doc if replace else lib.dict_merge(lib.json_loads(rdoc["_json"]), doc)
             _doc["_modified_at"] = ts
             _restricted_columns = self.DEFAULT_COLUMNS[:]
 
             xcolumns = ["_json", "_modified_at"]
-            xparams = [lib.json_dumps(_doc), lib.timestamp_to_str(ts)]
+            xparams = [lib.json_dumps(_doc), ts_f]
 
             q = "UPDATE %s SET " % self.name
             
